@@ -34,15 +34,24 @@
 #include "pt_Types.h"
 
 #include "pp_AttrProp.h"
+#include "pp_Revision.h"
+#include "pd_Style.h"
+#include "pd_Document.h"
+
+
 
 /****************************************************************/
 PP_AttrProp::PP_AttrProp()
 {
 	m_pAttributes = NULL;
 	m_pProperties = NULL;
+	m_szProperties = NULL;
 	m_bIsReadOnly = false;
 	m_checkSum = 0;
 	xxx_UT_DEBUGMSG(("creating pp_AttrProp %x \n",this));
+
+	m_iRevisedIndex = 0xffffffff;
+	m_bRevisionHidden = false;
 }
 
 PP_AttrProp::~PP_AttrProp()
@@ -50,9 +59,9 @@ PP_AttrProp::~PP_AttrProp()
 	xxx_UT_DEBUGMSG(("deleting pp_AttrProp %x \n",this));
 	if (m_pAttributes)
 	{
-		UT_StringPtrMap::UT_Cursor c1(m_pAttributes);
+		UT_GenericStringMap<XML_Char*>::UT_Cursor c1(m_pAttributes);
 
-		const XML_Char * s = static_cast<const XML_Char *>(c1.first());
+		const XML_Char * s = c1.first();
 
 		while (true) {
 			FREEP(s);
@@ -60,7 +69,7 @@ PP_AttrProp::~PP_AttrProp()
 			if (!c1.is_valid())
 				break;
 
-			s = static_cast<const XML_Char *>(c1.next());
+			s = c1.next();
 		}
 
 		delete m_pAttributes;
@@ -71,18 +80,18 @@ PP_AttrProp::~PP_AttrProp()
 
 	if(m_pProperties)
 	{
-		UT_StringPtrMap::UT_Cursor c(m_pProperties);
-		const UT_Pair * entry = NULL;
-		for (entry = static_cast<const UT_Pair*>(c.first()); c.is_valid();
-		     entry = static_cast<const UT_Pair*>(c.next()))
+		UT_GenericStringMap<PropertyPair*>::UT_Cursor c(m_pProperties);
+		const PropertyPair * entry = NULL;
+
+		for (entry = c.first(); c.is_valid(); entry = c.next())
 		{
 			if(entry)
 			{
 				// hack. don't do it.
-				void* tmp = const_cast<void*> (entry->first());
+				XML_Char* tmp = (XML_Char*)entry->first();
 				FREEP(tmp);
 				if (entry->second())
-					delete static_cast<PP_PropertyType *const>(entry->second());
+					delete entry->second();
 				delete entry;
 			}
 		}
@@ -90,11 +99,18 @@ PP_AttrProp::~PP_AttrProp()
 		delete m_pProperties;
 		m_pProperties = NULL;
 	}
-
+	if(m_szProperties)
+	{
+		delete [] m_szProperties;
+	}
+	m_szProperties = NULL;
 }
 
 /*!
  * Returns the number of properties in this PP_AttrProp.
+ *
+ * BE WEARY, BE VERY WEARY, the count can be greater than the number of valid items
+ * stored in the hash -- always check the return value of getNthProperty()
  */
 size_t PP_AttrProp::getPropertyCount (void) const
 {
@@ -106,6 +122,9 @@ size_t PP_AttrProp::getPropertyCount (void) const
 
 /*!
  * Returns the number of attributes in this PP_AttrProp.
+ *
+ * BE WEARY, BE VERY WEARY, the count can be greater than the number of valid items
+ * stored in the hash -- always check the return value of getNthAttribute()
  */
 size_t PP_AttrProp::getAttributeCount (void) const
 {
@@ -143,13 +162,13 @@ bool	PP_AttrProp::setAttributes(const XML_Char ** attributes)
  *
  * \param attributes A UT_Vector of strings, read in (attribute, value) form.
  */
-bool PP_AttrProp::setAttributes(const UT_Vector * pVector)
+bool PP_AttrProp::setAttributes(const UT_GenericVector<XML_Char*> * pVector)
 {
 	UT_uint32 kLimit = pVector->getItemCount();
 	for (UT_uint32 k=0; k+1<kLimit; k+=2)
 	{
-		const XML_Char * pName = static_cast<XML_Char *>(pVector->getNthItem(k));
-		const XML_Char * pValue = static_cast<XML_Char *>(pVector->getNthItem(k+1));
+		const XML_Char * pName = pVector->getNthItem(k);
+		const XML_Char * pValue = pVector->getNthItem(k+1);
 		if (!setAttribute(pName,pValue))
 			return false;
 	}
@@ -181,13 +200,13 @@ bool	PP_AttrProp::setProperties(const XML_Char ** properties)
  *
  * \param pVector A UT_Vector of strings, read in (properties, value) form.
  */
-bool PP_AttrProp::setProperties(const UT_Vector * pVector)
+bool PP_AttrProp::setProperties(const UT_GenericVector<XML_Char*> * pVector)
 {
 	UT_uint32 kLimit = pVector->getItemCount();
 	for (UT_uint32 k=0; k+1<kLimit; k+=2)
 	{
-		const XML_Char * pName = static_cast<XML_Char *>(pVector->getNthItem(k));
-		const XML_Char * pValue = static_cast<XML_Char *>(pVector->getNthItem(k+1));
+		const XML_Char * pName = pVector->getNthItem(k);
+		const XML_Char * pValue = pVector->getNthItem(k+1);
 		if (!setProperty(pName,pValue))
 			return false;
 	}
@@ -206,9 +225,9 @@ bool PP_AttrProp::setProperties(const UT_Vector * pVector)
 bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue)
 {
 	// TODO when this assert fails, switch this file to use UT_XML_ version of str*() functions.
-	UT_ASSERT(sizeof(char)==sizeof(XML_Char));
+	UT_return_val_if_fail (sizeof(char)==sizeof(XML_Char), false);
 
-	if (0 == UT_strcmp(szName, PT_PROPS_ATTRIBUTE_NAME) && *szValue)	// PROPS -- cut value up into properties
+	if (0 == strcmp(szName, PT_PROPS_ATTRIBUTE_NAME) && *szValue)	// PROPS -- cut value up into properties
 	{
 		char * pOrig = NULL;
 		
@@ -239,6 +258,7 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 			if (!*q)
 			{
 				free(pOrig);
+				UT_DEBUGMSG(("props: %s\n", szValue));
 				return false;
 			}
 
@@ -265,7 +285,7 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 			while (isspace(*q))
 				q++;
 
-			setProperty(static_cast<const XML_Char*>(p), static_cast<const XML_Char*>(q));
+			setProperty(p, q);
 		}
 
 		free(pOrig);
@@ -275,7 +295,7 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 	{
 		if (!m_pAttributes)
 		{
-			m_pAttributes = new UT_StringPtrMap(5);
+			m_pAttributes = new UT_GenericStringMap<XML_Char*>(5);
 			if (!m_pAttributes)
 			{
 				UT_DEBUGMSG(("setAttribute: could not allocate hash table.\n"));
@@ -284,7 +304,7 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 		}
 
 		// make sure we store attribute names in lowercase
-		UT_ASSERT(sizeof(char) == sizeof(XML_Char));
+		UT_ASSERT_HARMLESS(sizeof(char) == sizeof(XML_Char));
 
 		char * copy;
 		if (!UT_cloneString(copy, szName))
@@ -294,11 +314,26 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 		}
 
 		UT_lowerString(copy);
-		char * szDupValue = UT_strdup(szValue);
+		char * szDupValue = szValue ? UT_strdup(szValue) : NULL;
 
-		if(!m_pAttributes->insert(copy, static_cast<void *>(szDupValue)))
-			FREEP(szDupValue);
+		const char * pEntry = m_pAttributes->pick(copy);
 
+		if(pEntry)
+		{
+			// attribute exists, replace it
+			FREEP(pEntry);
+			m_pAttributes->set(copy, szDupValue);
+		}
+		else
+		{
+			bool bRet = m_pAttributes->insert(copy, szDupValue);
+			UT_ASSERT_HARMLESS( bRet );
+			if(!bRet)
+			{
+				FREEP(szDupValue);
+			}
+		}
+		
 		FREEP(copy);
 
 		return true;
@@ -309,7 +344,7 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 {
 	if (!m_pProperties)
 	{
-		m_pProperties = new UT_StringPtrMap(5);
+		m_pProperties = new UT_GenericStringMap<PropertyPair*>(5);
 		if (!m_pProperties)
 		{
 			UT_DEBUGMSG(("setProperty: could not allocate hash table.\n"));
@@ -317,68 +352,56 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 		}
 	}
 
-#if 0
-	// no. we have to set it empty, otherwise the code that changes
+	// if szValue == NULL or *szValue == 0, indicates absent property.
+	// We have to set it empty, otherwise the code that changes
 	// properties has no way of knowing that this property is not to
 	// be present
 	// 
-	// if szValue == NULL or *szValue == 0, we want this property
-	// removed
-	bool bRemove = (!szValue || !*szValue);
-#endif
-	const void * pEntry = m_pProperties->pick(szName);
+	//bool bRemove = (!szValue || !*szValue);
+	
+	const PropertyPair * pEntry = m_pProperties->pick(szName);
 	if (pEntry)
 	{
-		const UT_Pair* p = static_cast<const UT_Pair*>(pEntry);
+		const PropertyPair* p = pEntry;
 
 		// hack. don't do it.
-		void* tmp = const_cast<void*> (p->first());
-		UT_ASSERT(!m_bIsReadOnly);
-		if(UT_strcmp(szName,"line-height") == 0)
+		XML_Char* tmp = (XML_Char*)p->first();
+		UT_return_val_if_fail (!m_bIsReadOnly, false);
+		if(strcmp(szName,"line-height") == 0)
 		{
 			UT_DEBUGMSG(("Found line-height, Old value %s new value is %s \n",tmp,szValue));
 		}
 
 		FREEP(tmp);
 		if (p->second())
-			delete static_cast<PP_PropertyType *const>(p->second());
+			delete p->second();
 		delete p;
-#if 0
-		if(bRemove)
-		{
-			m_pProperties->remove(szName,NULL);
-		}
-		else
-#endif
-		{
-			m_pProperties->set(szName,
-							   static_cast<void *>(new UT_Pair(UT_strdup(szValue), static_cast<void *>(NULL))));
-		}
-		
+		m_pProperties->set(szName, new PropertyPair(szValue ? UT_strdup(szValue) : NULL, NULL));
 	}
 	else
 	{
-#if 0
-		if(!bRemove)
-#endif
-		{
-			m_pProperties->insert(szName,
-								  static_cast<void *>(new UT_Pair(UT_strdup(szValue), static_cast<void *>(NULL))));
-		}
+		m_pProperties->insert(szName, new PropertyPair(szValue ? UT_strdup(szValue) : NULL, NULL));
 	}
 	return true;
 }
 
+/*!
+    Always check the return value before trying to work with szValue !!!
+*/
 bool	PP_AttrProp::getNthAttribute(int ndx, const XML_Char *& szName, const XML_Char *& szValue) const
 {
 	if (!m_pAttributes)
 		return false;
 	if (static_cast<UT_uint32>(ndx) >= m_pAttributes->size())
+	{
+		// UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN ); -- do not assert, some code in
+		// while loops relies on this
 		return false;
-
+	}
+	
 	int i = 0;
-	UT_StringPtrMap::UT_Cursor c(m_pAttributes);
-	const void * val = NULL;
+	UT_GenericStringMap<XML_Char*>::UT_Cursor c(m_pAttributes);
+	const XML_Char * val = NULL;
 
 	for (val = c.first(); (c.is_valid() && (i < ndx)); val = c.next(), i++)
 	{
@@ -387,24 +410,31 @@ bool	PP_AttrProp::getNthAttribute(int ndx, const XML_Char *& szName, const XML_C
 
 	if ((i == ndx) && c.is_valid())
 	  {
-	    szName = static_cast<const XML_Char*>(c.key().c_str());
-	    szValue = static_cast<const XML_Char*>(val);
+	    szName = c.key().c_str();
+	    szValue = val;
 	    return true;
 	  }
 	return false;
 }
 
+/*!
+    Always check the return value before trying to work with szValue !!!
+*/
 bool	PP_AttrProp::getNthProperty(int ndx, const XML_Char *& szName, const XML_Char *& szValue) const
 {
 	if (!m_pProperties)
 		return false;
 
  	if (static_cast<UT_uint32>(ndx) >= m_pProperties->size())
+	{
+		// UT_ASSERT_HARMLESS( UT_SHOULD_NOT_HAPPEN ); -- do not assert, some code in
+		// while loops relies on this
   		return false;
-
+	}
+	
  	int i = 0;
- 	UT_StringPtrMap::UT_Cursor c(m_pProperties);
- 	const void * val = NULL;
+	UT_GenericStringMap<PropertyPair*>::UT_Cursor c(m_pProperties);
+ 	const PropertyPair * val = NULL;
 
 	for (val = c.first(); (c.is_valid() && (i < ndx)); val = c.next(), i++)
  	{
@@ -413,8 +443,8 @@ bool	PP_AttrProp::getNthProperty(int ndx, const XML_Char *& szName, const XML_Ch
 
 	if ( (i == ndx) && c.is_valid())
  		{
-		  szName = static_cast<const XML_Char*>(c.key().c_str());
-		  szValue = static_cast<XML_Char* const>(static_cast<const UT_Pair*>(val)->first());
+		  szName = c.key().c_str();
+		  szValue = val->first();
 		  return true;
  		}
 	return false;
@@ -424,47 +454,75 @@ bool PP_AttrProp::getProperty(const XML_Char * szName, const XML_Char *& szValue
 {
 	if (!m_pProperties)
 		return false;
+	const PropertyPair * pEntry = m_pProperties->pick(szName);
 
-	const void * pEntry = m_pProperties->pick(szName);
 	if (!pEntry)
 		return false;
 
-	szValue = static_cast<XML_Char *const>(static_cast<const UT_Pair*>(pEntry)->first());
-
+	szValue = pEntry->first();
 	return true;
 }
+/*!
+ * Do not free this memory. It's cached here.
+ */
+const XML_Char ** PP_AttrProp::getProperties () const
+{
+	if(!m_pProperties)
+		return NULL;
+	if(m_szProperties != NULL)
+	{
+		return m_szProperties;
+	}
+	UT_uint32 iPropsCount = m_pProperties->size();
+	m_szProperties = new const XML_Char * [iPropsCount*2+2];
+
+	const XML_Char ** pList = m_pProperties->list();
+	UT_uint32 i = 0;
+
+	
+	// where the values should be, we actually have pointers to PropertyPair;
+	for(i = 1; i < iPropsCount * 2; i += 2)
+	{
+		PropertyPair * pP = (PropertyPair *) pList[i];
+		m_szProperties[i-1] = pList[i-1];
+		m_szProperties[i] = pP->first();
+	}
+	m_szProperties[i-1] = NULL;
+	m_szProperties[i] = NULL;
+	return m_szProperties;
+}
+
 
 const PP_PropertyType *PP_AttrProp::getPropertyType(const XML_Char * szName, tProperty_type Type) const
 {
 	if (!m_pProperties)
 		return NULL;
 
-	const UT_Pair * pEntry = static_cast<const UT_Pair *>(m_pProperties->pick(szName));
+	const PropertyPair * pEntry = m_pProperties->pick(szName);
 	if (!pEntry)
 		return NULL;
 
 	if(!pEntry->second())
 	{
-		m_pProperties->set(szName, new UT_Pair
-				   (pEntry->first(),
-				    PP_PropertyType::createPropertyType(Type,
-									static_cast<XML_Char *const>(pEntry->first()))));
+		m_pProperties->set(szName, new PropertyPair(pEntry->first(),
+				    PP_PropertyType::createPropertyType(Type,pEntry->first())));
 		delete pEntry;
-		pEntry = static_cast<const UT_Pair *>(m_pProperties->pick(szName));
+		pEntry = m_pProperties->pick(szName);
 	}
 
-	return static_cast<PP_PropertyType *const>(pEntry->second());
+	return pEntry->second();
 }
+
 bool PP_AttrProp::getAttribute(const XML_Char * szName, const XML_Char *& szValue) const
 {
 	if (!m_pAttributes)
 		return false;
 
-	const void * pEntry = m_pAttributes->pick(szName);
+	const XML_Char * pEntry = m_pAttributes->pick(szName);
 	if (!pEntry)
 		return false;
 
-	szValue = static_cast<const XML_Char *>(pEntry);
+	szValue = pEntry;
 
 
 	xxx_UT_DEBUGMSG(("SEVIOR: getAttribute Found value %s \n",szValue));
@@ -503,11 +561,11 @@ bool PP_AttrProp::areAlreadyPresent(const XML_Char ** attributes, const XML_Char
 				at least for the 'param' attribute which goes with fields.
 				Is this bogus too? -PL
 			*/
-			UT_ASSERT(p[1] /* && *p[1]*/);	// require value for each name
+			UT_return_val_if_fail (p[1] /* && *p[1]*/, false);	// require value for each name
 			const XML_Char * szValue = NULL;
 			if (!getAttribute(p[0],szValue))
 				return false;		// item not present
-			if (UT_XML_stricmp(p[1],szValue)!=0)
+			if (strcmp(p[1],szValue)!=0)
 				return false;		// item has different value
 			p += 2;
 		}
@@ -523,11 +581,11 @@ bool PP_AttrProp::areAlreadyPresent(const XML_Char ** attributes, const XML_Char
 				*want* to represent no tabstops as an empty string.
 				If this isn't safe, let me know.   -- PCR
 			*/
-			UT_ASSERT(p[1] /* && *p[1] */);	// require value for each name
+			UT_return_val_if_fail (p[1] /* && *p[1] */, false);	// require value for each name
 			const XML_Char * szValue = NULL;
 			if (!getProperty(p[0],szValue))
 				return false;		// item not present
-			if (UT_XML_stricmp(p[1],szValue)!=0)
+			if (strcmp(p[1],szValue)!=0)
 				return false;		// item has different value
 			p += 2;
 		}
@@ -587,8 +645,8 @@ bool PP_AttrProp::isExactMatch(const PP_AttrProp * pMatch) const
 	s_Calls++;
 #endif
 
-	UT_ASSERT(pMatch);
-	UT_ASSERT(m_bIsReadOnly && pMatch->m_bIsReadOnly);
+	UT_return_val_if_fail (pMatch, false);
+	UT_return_val_if_fail (m_bIsReadOnly && pMatch->m_bIsReadOnly, false);
 	if (m_checkSum != pMatch->m_checkSum)
 		return false;
 
@@ -608,24 +666,24 @@ bool PP_AttrProp::isExactMatch(const PP_AttrProp * pMatch) const
 
 	if (countMyAttrs != 0)
 	{
-		UT_StringPtrMap::UT_Cursor ca1(m_pAttributes);
-		UT_StringPtrMap::UT_Cursor ca2(pMatch->m_pAttributes);
+		UT_GenericStringMap<XML_Char*>::UT_Cursor ca1(m_pAttributes);
+		UT_GenericStringMap<XML_Char*>::UT_Cursor ca2(pMatch->m_pAttributes);
 
-		const void * v1 = ca1.first();
-		const void * v2 = ca2.first();
+		const XML_Char * v1 = ca1.first();
+		const XML_Char * v2 = ca2.first();
 
 		do
 		{
-			const XML_Char *l1 = static_cast<const XML_Char *>(ca1.key().c_str());
-			const XML_Char *l2 = static_cast<const XML_Char *>(ca2.key().c_str());
+			const XML_Char *l1 = ca1.key().c_str();
+			const XML_Char *l2 = ca2.key().c_str();
 
-			if (UT_XML_stricmp(l1, l2) != 0)
+			if (strcmp(l1, l2) != 0)
 				return false;
 
-			l1 = static_cast<const XML_Char *>(v1);
-			l2 = static_cast<const XML_Char *>(v2);
+			l1 = v1;
+			l2 = v2;
 
-			if (UT_XML_stricmp(l1,l2) != 0)
+			if (strcmp(l1,l2) != 0)
 				return false;
 
 			v1 = ca1.next();
@@ -635,24 +693,24 @@ bool PP_AttrProp::isExactMatch(const PP_AttrProp * pMatch) const
 
 	if (countMyProps > 0)
 	{
-		UT_StringPtrMap::UT_Cursor cp1(m_pProperties);
-		UT_StringPtrMap::UT_Cursor cp2(pMatch->m_pProperties);
+		UT_GenericStringMap<PropertyPair*>::UT_Cursor cp1(m_pProperties);
+		UT_GenericStringMap<PropertyPair*>::UT_Cursor cp2(pMatch->m_pProperties);
 
-		const void * v1 = cp1.first();
-		const void * v2 = cp2.first();
+		const PropertyPair* v1 = cp1.first();
+		const PropertyPair* v2 = cp2.first();
 
 		do
 		{
-			const XML_Char *l1 = static_cast<const XML_Char *>(cp1.key().c_str());
-			const XML_Char *l2 = static_cast<const XML_Char *>(cp2.key().c_str());
+			const XML_Char *l1 = cp1.key().c_str();
+			const XML_Char *l2 = cp2.key().c_str();
 
-			if (UT_XML_stricmp(l1, l2) != 0)
+			if (strcmp(l1, l2) != 0)
 				return false;
 
-			l1 = (XML_Char *) (static_cast<const UT_Pair*>(v1))->first();;
-			l2 = (XML_Char *) (static_cast<const UT_Pair*>(v2))->first();;
+			l1 = v1->first();
+			l2 = v2->first();
 
-			if (UT_XML_stricmp(l1,l2) != 0)
+			if (strcmp(l1,l2) != 0)
 				return false;
 
 			v1 = cp1.next();
@@ -704,7 +762,7 @@ PP_AttrProp * PP_AttrProp::cloneWithReplacements(const XML_Char ** attributes,
 		// TODO them from this?  or should we expand it and override
 		// TODO individual properties?
 		// TODO for now, we just barf on it.
-		UT_ASSERT(UT_XML_stricmp(n,PT_PROPS_ATTRIBUTE_NAME)!=0); // cannot handle PROPS here
+		UT_return_val_if_fail (strcmp(n,PT_PROPS_ATTRIBUTE_NAME)!=0, false); // cannot handle PROPS here
 		if (!papNew->getAttribute(n,vNew))
 			if (!papNew->setAttribute(n,v))
 				goto Failed;
@@ -749,46 +807,54 @@ void PP_AttrProp::_clearEmptyProperties()
 	if(!m_pProperties)
 		return;
 
-	UT_StringPtrMap::UT_Cursor _hc1(m_pProperties);
-	const void * pEntry;
+	UT_GenericStringMap<PropertyPair*>::UT_Cursor _hc1(m_pProperties);
+	PropertyPair * pEntry;
 
-	for ( pEntry  = static_cast<const UT_Pair*>(_hc1.first()); _hc1.is_valid(); pEntry = static_cast<const UT_Pair*>(_hc1.next()) )
+	for ( pEntry  = _hc1.first(); _hc1.is_valid(); pEntry = _hc1.next())
 	{
 		if (pEntry)
 		{
-			const UT_Pair* p = static_cast<const UT_Pair*>(pEntry);
+			const PropertyPair* p = pEntry;
 
-			if(*(static_cast<XML_Char *const>(p->first())) == 0)
+			if(*(p->first()) == 0)
 			{
 
-				void* tmp = const_cast<void*> (p->first());
-				UT_ASSERT(!m_bIsReadOnly);
+				XML_Char* tmp = const_cast<XML_Char*>(p->first());
+				UT_return_if_fail (!m_bIsReadOnly);
 				FREEP(tmp);
-				if (p->second())
-					delete static_cast<PP_PropertyType *const>(p->second());
+				m_pProperties->remove(_hc1.key(),pEntry);
+				if (p->second()) {
+					delete p->second();
+				}
 				delete p;
 
-				m_pProperties->remove(_hc1.key(),pEntry);
 			}
 		}
 	}
 }
 
+void PP_AttrProp::prune()
+{
+	_clearEmptyAttributes();
+	_clearEmptyProperties();
+}
+
+
 void PP_AttrProp::_clearEmptyAttributes()
 {
 	if(!m_pAttributes)
 		return;
 
-	UT_StringPtrMap::UT_Cursor _hc1(m_pAttributes);
-	const XML_Char * pEntry;
+	UT_GenericStringMap<XML_Char*>::UT_Cursor _hc1(m_pAttributes);
+	XML_Char * pEntry;
 
-	for ( pEntry  = static_cast<const XML_Char*>(_hc1.first()); _hc1.is_valid(); pEntry = static_cast<const XML_Char*>(_hc1.next()) )
+	for ( pEntry  = _hc1.first(); _hc1.is_valid(); pEntry = _hc1.next())
 	{
 		if (pEntry && !*pEntry)
 		{
-			UT_ASSERT(!m_bIsReadOnly);
-			FREEP(pEntry);
+			UT_return_if_fail (!m_bIsReadOnly);
 			m_pAttributes->remove(_hc1.key(),pEntry);
+			FREEP(pEntry);
 		}
 	}
 }
@@ -821,8 +887,8 @@ PP_AttrProp * PP_AttrProp::cloneWithElimination(const XML_Char ** attributes,
 			const XML_Char ** p = attributes;
 			while (*p)
 			{
-				UT_ASSERT(UT_XML_stricmp(p[0],PT_PROPS_ATTRIBUTE_NAME)!=0); // cannot handle PROPS here
-				if (UT_XML_stricmp(n,p[0])==0)		// found it, so we don't put it in the result.
+				UT_return_val_if_fail (strcmp(p[0],PT_PROPS_ATTRIBUTE_NAME)!=0, false); // cannot handle PROPS here
+				if (strcmp(n,p[0])==0)		// found it, so we don't put it in the result.
 					goto DoNotIncludeAttribute;
 				p += 2;								// skip over value
 			}
@@ -848,7 +914,7 @@ PP_AttrProp * PP_AttrProp::cloneWithElimination(const XML_Char ** attributes,
 			const XML_Char ** p = properties;
 			while (*p)
 			{
-				if (UT_XML_stricmp(n,p[0])==0)		// found it, so we don't put it in the result.
+				if (strcmp(n,p[0])==0)		// found it, so we don't put it in the result.
 					goto DoNotIncludeProperty;
 				p += 2;
 			}
@@ -872,7 +938,7 @@ Failed:
 
 void PP_AttrProp::markReadOnly(void)
 {
-	UT_ASSERT(!m_bIsReadOnly);
+	UT_return_if_fail (!m_bIsReadOnly);
 	m_bIsReadOnly = true;
 	_computeCheckSum();
 }
@@ -905,8 +971,9 @@ PP_AttrProp * PP_AttrProp::cloneWithEliminationIfEqual(const XML_Char ** attribu
 			const XML_Char ** p = attributes;
 			while (*p)
 			{
-				UT_ASSERT(UT_XML_stricmp(p[0],PT_PROPS_ATTRIBUTE_NAME)!=0); // cannot handle PROPS here
-				if (UT_XML_stricmp(n,p[0])==0 && UT_XML_stricmp(n,p[1])==0)		// found it, so we don't put it in the result.
+				if(strcmp(p[0],PT_PROPS_ATTRIBUTE_NAME)!=0)
+					goto DoNotIncludeAttribute; // cannot handle PROPS here
+				if (strcmp(n,p[0])==0 && strcmp(n,p[1])==0)		// found it, so we don't put it in the result.
 					goto DoNotIncludeAttribute;
 				p += 2;								// skip over value
 			}
@@ -932,7 +999,7 @@ PP_AttrProp * PP_AttrProp::cloneWithEliminationIfEqual(const XML_Char ** attribu
 			const XML_Char ** p = properties;
 			while (*p)
 			{
-				if (UT_XML_stricmp(n,p[0])==0 && UT_XML_stricmp(n,p[1])==0)		// found it, so we don't put it in the result.
+				if (strcmp(n,p[0])==0 && strcmp(n,p[1])==0)		// found it, so we don't put it in the result.
 					goto DoNotIncludeProperty;
 				p += 2;
 			}
@@ -954,61 +1021,104 @@ Failed:
 	return NULL;
 }
 
+  
+static UT_uint32 hashcodeBytesAP(UT_uint32 init, const void * pv, UT_uint32 cb)
+{
+ 	// modified from ut_string_class.cpp's hashcode() which got it from glib
+ 	UT_uint32 h = init;
+ 	const unsigned char * pb = static_cast<const unsigned char *>(pv);
+ 
+ 	if (cb)
+ 	{
+ 		// for AP data, limit hash to consume at most 8 bytes
+ 		if (cb > 8) { cb = 8; }
+ 
+ 		for (; cb != 0; pb += 1, cb -= 1)
+ 		{
+ 			h = (h << 5) - h + *pb;
+ 		}
+ 	}
+ 	
+ 	return h;
+}
+
+
 void PP_AttrProp::_computeCheckSum(void)
 {
 	m_checkSum = 0;
-
-	// compute some easy-to-compute checksum for this AP. something
-	// that is guaranteed to return the same result for the same input.
-	// something that we can use like a hash for a quick check in
-	// isExactMatch() to quickly dismiss different APs.  it should be
-	// based strictly on the content of the name/value pairs and be
-	// pointer- and order-independent.
-
-	if (!m_pAttributes || !m_pProperties)
-		return;
-
+ 
+ 	if (!m_pAttributes && !m_pProperties)
+  		return;
+ 
 	const XML_Char * s1, *s2;
-
-	UT_StringPtrMap::UT_Cursor c1(m_pAttributes);
-	UT_StringPtrMap::UT_Cursor c2(m_pProperties);
-
-	const void *val = c1.first();
-
-	while (val != NULL)
-	{
-		s1 = static_cast<const XML_Char *>(c1.key().c_str());
-		s2 = static_cast<const XML_Char *>(val);
-
-		m_checkSum += UT_XML_strlen(s1);
-		m_checkSum += UT_XML_strlen(s2);
-
-		if (!c1.is_valid())
-			break;
-		val = c1.next();
+ 	UT_uint32	cch = 0;
+ 	XML_Char	rgch[9];
+  
+ 	rgch[8] = 0;
+  
+ 	if (m_pAttributes)
+  	{
+ 		UT_GenericStringMap<XML_Char*>::UT_Cursor c1(m_pAttributes);
+ 		const XML_Char *val = c1.first();
+ 
+ 		while (val != NULL)
+ 		{
+ 			s1 = c1.key().c_str();
+ 			s2 = val;
+  
+ 			cch = UT_XML_strlen(s1);
+  
+ 			m_checkSum = hashcodeBytesAP(m_checkSum, s1, cch);
+ 
+ 			cch = UT_XML_strlen(s2);
+ 
+ 			UT_XML_strncpy(rgch, 8, s2);
+ 			UT_lowerString(rgch);
+  
+ 			m_checkSum = hashcodeBytesAP(m_checkSum, rgch, cch);
+  
+ 			if (!c1.is_valid())
+ 				break;
+ 			val = c1.next();
+ 		}
+ 	}
+ 
+ 	if (m_pProperties)
+  	{
+ 		UT_GenericStringMap<PropertyPair*>::UT_Cursor c2(m_pProperties);
+ 		const PropertyPair *val;
+ 
+ 		val = c2.first();
+ 		while (val != NULL)
+ 		{
+ 			s1 = c2.key().c_str();
+ 			s2 = val->first();
+ 
+ 			cch = UT_XML_strlen(s1);
+ 
+ 			UT_XML_strncpy(rgch, 8, s1);
+ 			UT_lowerString(rgch);
+ 
+ 			m_checkSum = hashcodeBytesAP(m_checkSum, rgch, cch);
+  
+ 			cch = UT_XML_strlen(s2);
+  
+ 			UT_XML_strncpy(rgch, 8, s2);
+ 			UT_lowerString(rgch);
+ 
+ 			m_checkSum = hashcodeBytesAP(m_checkSum, rgch, cch);
+ 
+ 			if (!c2.is_valid())
+ 				break;
+ 			val = c2.next();
+ 		}
 	}
-
-
-	val = c2.first();
-	while (val != NULL)
-	{
-		s1 = static_cast<const XML_Char *>(c2.key().c_str());
-		s2 = static_cast<XML_Char *const>(static_cast<const UT_Pair*>(val)->first());
-
-		m_checkSum += UT_XML_strlen(s1);
-		m_checkSum += UT_XML_strlen(s2);
-
-		if (!c2.is_valid())
-			break;
-		val = c2.next();
-	}
-
 	return;
 }
 
 UT_uint32 PP_AttrProp::getCheckSum(void) const
 {
-	UT_ASSERT(m_bIsReadOnly);
+	UT_ASSERT_HARMLESS(m_bIsReadOnly);
 	return m_checkSum;
 }
 
@@ -1041,3 +1151,250 @@ void PP_AttrProp::operator = (const PP_AttrProp &Other)
 
 }
 
+UT_uint32 PP_AttrProp::getIndex(void)
+{
+	return m_index;
+}
+
+void PP_AttrProp::setIndex(UT_uint32 i)
+{
+	m_index = i;
+	if(m_szProperties)
+	{
+		delete [] m_szProperties;
+	}
+	m_szProperties = NULL;
+}
+
+/*!
+    in contrast to is isExactMatch this function will return true if
+    the attrs and props are same even if they are in different order;
+    it is computationally much more involved than isExactMatch()
+*/
+bool PP_AttrProp::isEquivalent(const PP_AttrProp * pAP2) const
+{
+	if(!pAP2)
+		return false;
+	
+	if(   getAttributeCount() != pAP2->getAttributeCount()
+	   || getPropertyCount()  != pAP2->getPropertyCount())
+		return false;
+	
+	UT_uint32 i;
+	const XML_Char * pName, * pValue, * pValue2;
+	
+	for(i =  0; i < getAttributeCount(); ++i)
+	{
+		UT_return_val_if_fail(getNthAttribute(i,pName,pValue),false);
+
+		if(!pAP2->getAttribute(pName,pValue2))
+			return false;
+
+		// ignore property attribute
+		if(0 == UT_strcmp(pValue, PT_PROPS_ATTRIBUTE_NAME))
+			continue;
+
+		// handle revision attribute correctly
+		if(0 == UT_strcmp(pValue, PT_REVISION_ATTRIBUTE_NAME))
+		{
+			// requires special treatment
+			PP_RevisionAttr r1(pValue);
+			PP_RevisionAttr r2 (pValue2);
+
+			if(!(r1 == r2))
+			{
+				return false;
+			}
+		}
+		else if(0 != UT_strcmp(pValue,pValue2))
+			return false;
+	}
+
+	for(i =  0; i < getPropertyCount(); ++i)
+	{
+		UT_return_val_if_fail(getNthProperty(i,pName,pValue),false);
+
+		if(!pAP2->getProperty(pName,pValue2))
+			return false;
+
+		if(0 != UT_strcmp(pValue,pValue2))
+			return false;
+	}
+
+	return true;
+}
+
+bool PP_AttrProp::isEquivalent(const XML_Char ** attrs, const XML_Char ** props) const
+{
+	UT_uint32 iAttrsCount  = 0;
+	UT_uint32 iPropsCount = 0;
+
+	const XML_Char ** p = attrs;
+
+	while(p && *p)
+	{
+		iAttrsCount++;
+		p += 2;
+	}
+	
+	p = props;
+
+	while(p && *p)
+	{
+		iPropsCount++;
+		p += 2;
+	}
+
+	
+	if(   getAttributeCount() != iAttrsCount
+	   || getPropertyCount()  != iPropsCount)
+		return false;
+	
+	UT_uint32 i;
+	const XML_Char * pName, * pValue, * pValue2;
+	
+	for(i =  0; i < getAttributeCount(); ++i)
+	{
+		pName = attrs[2*i];
+		pValue = attrs[2*i + 1];
+
+		if(!getAttribute(pName,pValue2))
+			return false;
+
+		// ignore property attribute
+		if(0 == UT_strcmp(pValue, PT_PROPS_ATTRIBUTE_NAME))
+			continue;
+
+		// handle revision attribute correctly
+		if(0 == UT_strcmp(pValue, PT_REVISION_ATTRIBUTE_NAME))
+		{
+			// requires special treatment
+			PP_RevisionAttr r1(pValue);
+			PP_RevisionAttr r2 (pValue2);
+
+			if(!(r1 == r2))
+			{
+				return false;
+			}
+		}
+		else if(0 != UT_strcmp(pValue,pValue2))
+			return false;
+	}
+
+	for(i =  0; i < getPropertyCount(); ++i)
+	{
+		pName = props[2*i];
+		pValue = props[2*i + 1];
+
+		if(!getProperty(pName,pValue2))
+			return false;
+
+		if(0 != UT_strcmp(pValue,pValue2))
+			return false;
+	}
+
+	return true;
+}
+
+/*!
+    This function transfers attributes and properties defined in style into the AP
+
+    bOverwrite indicates what happens if the property/attribute is already present. If false
+    (default) the style definition is ignored; if true the style value overrides the present value
+*/
+bool PP_AttrProp::explodeStyle(const PD_Document * pDoc, bool bOverwrite)
+{
+	UT_return_val_if_fail(pDoc,false);
+	
+	// expand style if present
+	const XML_Char * pszStyle = NULL;
+	if(getAttribute(PT_STYLE_ATTRIBUTE_NAME, pszStyle))
+	{
+		PD_Style * pStyle = NULL;
+
+        if(pszStyle && (UT_strcmp(pszStyle, "None") != 0) && pDoc->getStyle(pszStyle,&pStyle))
+        {
+			UT_Vector vAttrs;
+			UT_Vector vProps;
+
+			UT_uint32 i;
+
+			pStyle->getAllAttributes(&vAttrs, 100);
+			pStyle->getAllProperties(&vProps, 100);
+
+			for(i = 0; i < vProps.getItemCount(); i += 2)
+			{
+				const XML_Char * pName =  (const XML_Char *)vProps.getNthItem(i);
+				const XML_Char * pValue = (const XML_Char *)vProps.getNthItem(i+1);
+				const XML_Char * p;
+
+				bool bSet = bOverwrite || !getProperty(pName, p);
+
+				if(bSet)
+					setProperty(pName, pValue);
+			}
+
+			// attributes are more complicated, because there are some style attributes that must
+			// not be transferred to the generic AP
+			for(i = 0; i < vAttrs.getItemCount(); i += 2)
+			{
+				const XML_Char * pName = (const XML_Char *)vAttrs.getNthItem(i);
+				if(!pName || !UT_strcmp(pName, "type")
+				          || !UT_strcmp(pName, "name")
+				          || !UT_strcmp(pName, "basedon")
+				          || !UT_strcmp(pName, "followedby")
+ 				          || !UT_strcmp(pName, "props"))
+				{
+					continue;
+				}
+
+				const XML_Char * pValue = (const XML_Char *)vAttrs.getNthItem(i+1);
+				const XML_Char * p;
+
+				bool bSet = bOverwrite || !getAttribute(pName, p);
+
+				if(bSet)
+					setAttribute(pName, pValue);
+			}
+		}
+	}
+
+	return true;
+}
+
+void PP_AttrProp::miniDump(const PD_Document * pDoc) const
+{
+#ifdef DEBUG
+	const XML_Char * pName, * pValue;
+	UT_uint32 i = 0;
+	
+	UT_DEBUGMSG(("--------------------- PP_AttrProp mini dump --------------------------------\n"));
+	UT_DEBUGMSG(("Attributes:\n"));
+	while(getNthAttribute(i,pName,pValue))
+	{
+		UT_DEBUGMSG(("%s : %s\n", pName, pValue));
+		++i;
+	}
+		  
+	UT_DEBUGMSG(("Properties:\n"));
+	i = 0;
+	while(getNthProperty(i,pName,pValue))
+	{
+		UT_DEBUGMSG(("%s : %s\n", pName, pValue));
+		++i;
+	}
+
+	if(m_iRevisedIndex != 0xffffffff && pDoc)
+	{
+		UT_DEBUGMSG(("Attached revised AP:\n"));
+		const PP_AttrProp * pRevAP;
+		pDoc->getAttrProp(m_iRevisedIndex, const_cast<const PP_AttrProp **>(&pRevAP));
+
+		// avoid endless loop on circular reference
+		if(pRevAP && pRevAP->getRevisedIndex() != m_iRevisedIndex)
+			pRevAP->miniDump(pDoc);
+	}
+	
+	UT_DEBUGMSG(("----------------------------------------------------------------------------\n"));
+#endif
+}
