@@ -72,31 +72,6 @@ int AP_QNXDialog_Options::s_delete_clicked(PtWidget_t *widget, void *data, PtCal
 	return Pt_CONTINUE;
 }
 
-int AP_QNXDialog_Options::s_ignore_reset_clicked(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Options * dlg = (AP_QNXDialog_Options *)data;
-	UT_ASSERT(dlg);
-	dlg->_event_IgnoreReset();
-	return Pt_CONTINUE;
-}
-
-int AP_QNXDialog_Options::s_ignore_edit_clicked(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Options * dlg = (AP_QNXDialog_Options *)data;
-	UT_ASSERT(dlg);
-	dlg->_event_IgnoreEdit();
-	return Pt_CONTINUE;
-}
-
-int AP_QNXDialog_Options::s_dict_edit_clicked(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
-{
-	AP_QNXDialog_Options * dlg = (AP_QNXDialog_Options *)data;
-	UT_ASSERT(dlg);
-	printf("dict edit clicked \n");
-	dlg->_event_DictionaryEdit();
-	return Pt_CONTINUE;
-}
-
 int AP_QNXDialog_Options::s_defaults_clicked(PtWidget_t *widget, void *data, PtCallbackInfo_t *info)
 {
 	AP_QNXDialog_Options * dlg = (AP_QNXDialog_Options *)data;
@@ -323,6 +298,7 @@ PtWidget_t* AP_QNXDialog_Options::_constructWindow ()
 {
 	// for the internationalization
 	const XAP_StringSet * pSS = m_pApp->getStringSet();
+	UT_UTF8String s;
 
 	PtWidget_t *windowOptions;
 	PtWidget_t *buttonSave;
@@ -336,7 +312,6 @@ PtWidget_t* AP_QNXDialog_Options::_constructWindow ()
 	PtWidget_t *checkbuttonSpellMainOnly;
 	PtWidget_t *checkbuttonSpellUppercase;
 	PtWidget_t *checkbuttonSpellNumbers;
-	PtWidget_t *checkbuttonSpellInternet;
 	PtWidget_t *label4;
 	PtWidget_t *checkbuttonSpellCheckAsType;
 	PtWidget_t *buttonSpellIgnoreReset;
@@ -352,15 +327,11 @@ PtWidget_t* AP_QNXDialog_Options::_constructWindow ()
 	PtWidget_t *labelUnits;
 	PtWidget_t *listViewRulerUnit;
 	PtWidget_t *checkbuttonViewCursorBlink;
-	PtWidget_t *checkbuttonViewStandard;
-	PtWidget_t *checkbuttonViewFormat;
-	PtWidget_t *checkbuttonViewExtra;
 	PtWidget_t *checkbuttonViewStatusBar;
 	PtWidget_t *checkbuttonViewAll;
 	PtWidget_t *checkbuttonViewHidden;
 	PtWidget_t *checkbuttonViewUnprintable;
 	PtWidget_t *checkbuttonOtherDirectionRtl;
-	PtWidget_t *checkbuttonOtherSaveContextGlyphs;
 	PtWidget_t *checkbuttonOtherHebrewContextGlyphs;
 
 
@@ -373,7 +344,8 @@ PtWidget_t* AP_QNXDialog_Options::_constructWindow ()
 #define WIN_WIDTH  450
 #define WIN_HEIGHT 350
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, pSS->getValueUTF8(AP_STRING_ID_DLG_Options_OptionsTitle).utf8_str(), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_OptionsTitle,s);
+	PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, s.utf8_str(), 0);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_RENDER_FLAGS, 0, ABI_MODAL_WINDOW_RENDER_FLAGS);
 	PtSetArg(&args[n++], Pt_ARG_WINDOW_MANAGED_FLAGS, 0, ABI_MODAL_WINDOW_MANAGE_FLAGS);
 	windowOptions = PtCreateWidget(PtWindow, NULL, n, args);
@@ -405,7 +377,8 @@ PtSetArg(&args[n++], Pt_ARG_WINDOW_TITLE, pSS->getValueUTF8(AP_STRING_ID_DLG_Opt
 #define TAB_HEIGHT (PANEL_HEIGHT - 50)
 	/*** Spelling Tab ***/
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Spelling).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Spelling,s);
+PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, TAB_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, TAB_HEIGHT, 0);
 	PtWidget_t *spellingTab = PtCreateWidget(PtPane, panelGroup, n, args);
@@ -417,31 +390,33 @@ PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options
 	PtWidget_t *vspellgroup = PtCreateWidget(PtGroup, spellingTab, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellHideErrors).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellHideErrors,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellHideErrors = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Label_SpellSuggest).utf8_str()), 0);
+	pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Label_SpellSuggest,s),
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellSuggest = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Label_SpellMainOnly).utf8_str()), 0);
+	pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Label_SpellMainOnly,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellMainOnly = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellUppercase).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellUppercase,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellUppercase = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellNumbers).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellNumbers,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellNumbers = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellInternet).utf8_str()), 0);
-	checkbuttonSpellInternet = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
-
-	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellCheckAsType).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellCheckAsType,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonSpellCheckAsType = PtCreateWidget(PtToggleButton, vspellgroup, n, args);
 
 	/* Align these items horizontally */
@@ -450,7 +425,8 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 	PtWidget_t *hcustomdict = PtCreateWidget(PtGroup, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellCustomDict).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellCustomDict,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  3 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	label5 = PtCreateWidget(PtLabel, hcustomdict, n, args);
 
@@ -462,7 +438,8 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 	UT_QNXComboSetPos(listSpellDicts, 1);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Btn_CustomDict).utf8_str()), 0);
+	pSS->getValueUTF8( AP_STRING_ID_DLG_Options_Btn_CustomDict,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonSpellDictionary = PtCreateWidget(PtButton, hcustomdict, n, args);
 
@@ -472,23 +449,27 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8( AP_STRING_ID_DLG_
 	PtWidget_t *hignorewords = PtCreateWidget(PtGroup, vspellgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellIgnoredWord).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SpellIgnoredWord,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  3 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	label4 = PtCreateWidget(PtLabel, hignorewords, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_IgnoreReset).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_IgnoreReset,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonSpellIgnoreReset = PtCreateWidget(PtButton, hignorewords, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_IgnoreEdit).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_IgnoreEdit,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonSpellIgnoreEdit = PtCreateWidget(PtButton, hignorewords, n, args);
 
 	/*** Preferences Tab ***/
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Preferences ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Preferences,s);
+	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, TAB_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, TAB_HEIGHT, 0);
 	PtWidget_t *prefTab = PtCreateWidget(PtPane, panelGroup, n, args);
@@ -500,7 +481,8 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 	PtWidget_t *vprefgroup = PtCreateWidget(PtGroup, prefTab, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_PrefsAutoSave).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_PrefsAutoSave,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonPrefsAutoSave = PtCreateWidget(PtToggleButton, vprefgroup, n, args);
 
  	/** Group these together horizontally **/
@@ -509,7 +491,8 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 	PtWidget_t *hprefscheme = PtCreateWidget(PtGroup, vprefgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_PrefsCurrentScheme).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_PrefsCurrentScheme,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  3 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	label6 = PtCreateWidget(PtLabel, hprefscheme, n, args);
 
@@ -519,7 +502,8 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 
 	/*** View Tab ***/
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_View ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_View,s);
+	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, TAB_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, TAB_HEIGHT, 0);
 	PtWidget_t *viewTab = PtCreateWidget(PtPane, panelGroup, n, args);
@@ -532,7 +516,8 @@ PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options
 
 	/** View View Show/Hide **/
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewShowHide ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewShowHide,s);
+	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_CONTAINER_FLAGS, Pt_SHOW_TITLE | Pt_ETCH_TITLE_AREA,
 												 Pt_SHOW_TITLE | Pt_ETCH_TITLE_AREA);
 	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
@@ -545,12 +530,14 @@ PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options
 	PtWidget_t *hrulergroup = PtCreateWidget(PtGroup, vshowgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewRuler ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewRuler,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  2 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	checkbuttonViewRuler = PtCreateWidget(PtToggleButton, hrulergroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewUnits ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewUnits,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	labelUnits = PtCreateWidget(PtLabel, hrulergroup, n, args);
 
@@ -560,16 +547,20 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_O
 	listViewRulerUnit = PtCreateWidget(PtComboBox, hrulergroup, n, args);
 	//Populate the list with the units and set the vector
     m_vecUnits.clear();
-item = pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_inch).utf8_str();
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_inch,s);
+	item = s.utf8_str();
 	PtListAddItems(listViewRulerUnit, &item, 1, 0);
     m_vecUnits.addItem((void *)DIM_IN);
-item = pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_cm).utf8_str();
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_cm,s);
+	item = s.utf8_str();
 	PtListAddItems(listViewRulerUnit, &item, 1, 0);
     m_vecUnits.addItem((void *)DIM_CM);
-item = pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_points).utf8_str();
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_points,s);
+	item = s.utf8_str();
 	PtListAddItems(listViewRulerUnit, &item, 1, 0);
     m_vecUnits.addItem((void *)DIM_PT);
-item = pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_pica).utf8_str();
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_pica,s);
+	item = s.utf8_str();
 	PtListAddItems(listViewRulerUnit, &item, 1, 0);
     m_vecUnits.addItem((void *)DIM_PI);
 
@@ -578,28 +569,19 @@ item = pSS->getValueUTF8(XAP_STRING_ID_DLG_Unit_pica).utf8_str();
 	*/
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewStandardTB ).utf8_str()), 0);
-	checkbuttonViewStandard = PtCreateWidget(PtToggleButton, vshowgroup, n, args);
-
-	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewFormatTB ).utf8_str()), 0);
-	checkbuttonViewFormat = PtCreateWidget(PtToggleButton, vshowgroup, n, args);
-
-	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewExtraTB ).utf8_str()), 0);
-	checkbuttonViewExtra = PtCreateWidget(PtToggleButton, vshowgroup, n, args);
-
-	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewStatusBar ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewStatusBar,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonViewStatusBar = PtCreateWidget(PtToggleButton, vshowgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewCursorBlink ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewCursorBlink,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonViewCursorBlink = PtCreateWidget(PtToggleButton, vshowgroup, n, args);
 
 	/** View View Frame **/
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewViewFrame ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewViewFrame,s);
+	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_CONTAINER_FLAGS, Pt_SHOW_TITLE | Pt_ETCH_TITLE_AREA,
 												 Pt_SHOW_TITLE | Pt_ETCH_TITLE_AREA);
 	PtSetArg(&args[n++], Pt_ARG_GROUP_ORIENTATION, Pt_GROUP_VERTICAL, 0);
@@ -608,20 +590,24 @@ PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options
 	PtWidget_t *vviewviewgroup = PtCreateWidget (PtGroup, vviewgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewAll ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewAll,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonViewAll = PtCreateWidget(PtToggleButton, vviewviewgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewHiddenText ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewHiddenText,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonViewHidden = PtCreateWidget(PtToggleButton, vviewviewgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewUnprintable ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ViewUnprintable,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	checkbuttonViewUnprintable = PtCreateWidget(PtToggleButton, vviewviewgroup, n, args);
 
 	/*** Other/Misc Tab (smart quotes) ***/
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Other ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_TabLabel_Other,s);
+	PtSetArg(&args[n++], Pt_ARG_TITLE, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH, TAB_WIDTH, 0);
 	PtSetArg(&args[n++], Pt_ARG_HEIGHT, TAB_HEIGHT, 0);
 	PtWidget_t *miscTab = PtCreateWidget(PtPane, panelGroup, n, args);
@@ -634,8 +620,8 @@ PtSetArg(&args[n++], Pt_ARG_TITLE, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options
 
 	/** SmartQuotes Enable **/
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SmartQuotesEnable ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SmartQuotesEnable,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  2 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	m_checkbuttonSmartQuotesEnable = PtCreateWidget(PtToggleButton, vmiscgroup, n, args);
 
@@ -645,13 +631,13 @@ TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SmartQuotesEnable ).utf8_str
 	PtWidget_t *hautosavegroup = PtCreateWidget (PtGroup, vmiscgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_AutoSaveCurrent ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_AutoSaveCurrent,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,TR(s.utf8_str()), 0);
 	m_checkbuttonAutoSaveFile = PtCreateWidget(PtToggleButton, hautosavegroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_NUMERIC_SUFFIX,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_Minutes ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_Minutes,s);
+	PtSetArg(&args[n++], Pt_ARG_NUMERIC_SUFFIX,TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_MIN, 0, 0);
 	PtSetArg(&args[n++], Pt_ARG_NUMERIC_MAX, 60, 0);
 	m_wAutoSaveFilePeriod = PtCreateWidget(PtNumericInteger, hautosavegroup, n, args);
@@ -661,8 +647,8 @@ TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_Minutes ).utf8_str()), 0);
 	hautosavegroup = PtCreateWidget (PtGroup, vmiscgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_WithExtension ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_WithExtension,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,TR(s.utf8_str()), 0);
 	PtCreateWidget(PtLabel, hautosavegroup, n, args);
 
 	n = 0;
@@ -676,8 +662,8 @@ TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_WithExtension ).utf8_str()),
 	PtWidget_t *hcolorgroup = PtCreateWidget (PtGroup, vmiscgroup, n, args);
 
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ChooseForTransparent).utf8_str(), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ChooseForTransparent,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,s.utf8_str(), 0);
 	PtCreateWidget(PtLabel, hcolorgroup, n, args);
 
 	n = 0;
@@ -687,15 +673,17 @@ pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ChooseForTransparent).utf8_str(
 	//PtAddCallback(m_wCheckWhiteTransparent, Pt_CB_ACTIVATE, s_allowTransparentColor, this);
 
 	n = 0;
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_CheckWhiteForTransparent,s);
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_CheckWhiteForTransparent ).utf8_str()), 0);
+TR(s.utf8_str()), 0);
 	m_wCheckWhiteTransparent = PtCreateWidget(PtToggleButton, vmiscgroup, n, args);
 	PtAddCallback(m_wCheckWhiteTransparent, Pt_CB_ACTIVATE, s_allowTransparentColor, this);
 
 	/** Colour Selector Options **/
 	n = 0;
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ShowSplash,s);
 	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-	TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_ShowSplash ).utf8_str()), 0);
+	TR(s.utf8_str()), 0);
 	PtWidget_t *check_splash = PtCreateWidget (PtToggleButton, vmiscgroup, n, args);
 
 
@@ -707,18 +695,14 @@ TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_BiDiOptions ).utf8_str(), 0)
 	PtCreateWidget(PtGroup, vmiscgroup, n, args);
 */
 	n = 0;
-	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,
-TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_DirectionRtl ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_DirectionRtl,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING,TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  2 * ABI_DEFAULT_BUTTON_WIDTH, 0);
 	checkbuttonOtherDirectionRtl = PtCreateWidget(PtToggleButton, vmiscgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++],Pt_ARG_TEXT_STRING,TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_SaveContextGlyphs).utf8_str()),0);
-	PtSetArg(&args[n++],Pt_ARG_WIDTH,2*ABI_DEFAULT_BUTTON_WIDTH,0);
-	checkbuttonOtherSaveContextGlyphs = PtCreateWidget(PtToggleButton,vmiscgroup,n,args);
-
-	n = 0;
-PtSetArg(&args[n++],Pt_ARG_TEXT_STRING,TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_HebrewContextGlyphs).utf8_str()),0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Label_HebrewContextGlyphs,s);
+	PtSetArg(&args[n++],Pt_ARG_TEXT_STRING,TR(s.utf8_str()),0);
 	PtSetArg(&args[n++],Pt_ARG_WIDTH, 2* ABI_DEFAULT_BUTTON_WIDTH,0);
 	checkbuttonOtherHebrewContextGlyphs=PtCreateWidget(PtToggleButton,vmiscgroup,n,args);
 
@@ -729,27 +713,32 @@ PtSetArg(&args[n++],Pt_ARG_TEXT_STRING,TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Opt
 	PtWidget_t *hbuttongroup = PtCreateWidget (PtGroup, vallgroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Save ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Save,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonSave = PtCreateWidget(PtButton, hbuttongroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Apply ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Apply,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonApply = PtCreateWidget(PtButton, hbuttongroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Default ).utf8_str()), 0);
+	pSS->getValueUTF8(AP_STRING_ID_DLG_Options_Btn_Default,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonDefaults = PtCreateWidget(PtButton, hbuttongroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(XAP_STRING_ID_DLG_OK ).utf8_str()), 0);
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_OK,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonOk = PtCreateWidget(PtButton, hbuttongroup, n, args);
 
 	n = 0;
-PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel ).utf8_str()), 0);
+	pSS->getValueUTF8(XAP_STRING_ID_DLG_Cancel,s);
+	PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(s.utf8_str()), 0);
 	PtSetArg(&args[n++], Pt_ARG_WIDTH,  ABI_DEFAULT_BUTTON_WIDTH, 0);
 	buttonCancel = PtCreateWidget(PtButton, hbuttongroup, n, args);
 
@@ -758,16 +747,11 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(XAP_STRING_ID_DLG_
 	PtAddCallback(buttonCancel, Pt_CB_ACTIVATE, s_cancel_clicked, this);
 	PtAddCallback(buttonDefaults, Pt_CB_ACTIVATE, s_defaults_clicked, this);
 	PtAddCallback(buttonApply, Pt_CB_ACTIVATE, s_apply_clicked, this);
-	PtAddCallback(buttonSpellIgnoreEdit, Pt_CB_ACTIVATE, s_ignore_edit_clicked, this);
-	PtAddCallback(buttonSpellIgnoreReset, Pt_CB_ACTIVATE, s_ignore_reset_clicked, this);
-	PtAddCallback(buttonSpellDictionary, Pt_CB_ACTIVATE, s_dict_edit_clicked, this);
-
 
   m_windowMain = windowOptions;
   m_notebook = notebook1 = NULL;
 
   m_checkbuttonOtherDirectionRtl = checkbuttonOtherDirectionRtl;
-  m_checkbuttonOtherSaveContextGlyphs = checkbuttonOtherSaveContextGlyphs;
   m_checkbuttonOtherHebrewContextGlyphs = checkbuttonOtherHebrewContextGlyphs;
 
   m_checkbuttonSpellCheckAsType	= checkbuttonSpellCheckAsType;
@@ -776,7 +760,6 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(XAP_STRING_ID_DLG_
   m_checkbuttonSpellMainOnly		= checkbuttonSpellMainOnly;
   m_checkbuttonSpellUppercase		= checkbuttonSpellUppercase;
   m_checkbuttonSpellNumbers		= checkbuttonSpellNumbers;
-  m_checkbuttonSpellInternet		= checkbuttonSpellInternet;
   m_listSpellDicts				= listSpellDicts;
   m_listSpellDicts_menu			= listSpellDicts_menu = NULL;
   m_buttonSpellDictionary			= buttonSpellDictionary;
@@ -789,9 +772,6 @@ PtSetArg(&args[n++], Pt_ARG_TEXT_STRING, TR(pSS->getValueUTF8(XAP_STRING_ID_DLG_
   m_checkbuttonViewShowRuler		= checkbuttonViewRuler;
   m_listViewRulerUnits			= listViewRulerUnit;
   m_checkbuttonViewCursorBlink	= checkbuttonViewCursorBlink;
-  m_checkbuttonViewShowStandardBar	= checkbuttonViewStandard;
-  m_checkbuttonViewShowFormatBar	= checkbuttonViewFormat;
-  m_checkbuttonViewShowExtraBar	= checkbuttonViewExtra;
   m_checkbuttonViewShowStatusBar	= checkbuttonViewStatusBar;
   m_checkbuttonViewAll			= checkbuttonViewAll;
   m_checkbuttonViewHiddenText		= checkbuttonViewHidden;
@@ -838,26 +818,6 @@ PtWidget_t *AP_QNXDialog_Options::_lookupWidget ( tControl id )
 		return m_checkbuttonSpellNumbers;
 		break;
 
-	case id_CHECK_SPELL_INTERNET:
-		return m_checkbuttonSpellInternet;
-		break;
-
-	case id_LIST_DICTIONARY:
-		return m_listSpellDicts;
-		break;
-
-	case id_BUTTON_DICTIONARY_EDIT:
-		return m_buttonSpellDictionary;
-		break;
-
-	case id_BUTTON_IGNORE_RESET:
-		return m_buttonSpellIgnoreReset;
-		break;
-
-	case id_BUTTON_IGNORE_EDIT:
-		return m_buttonSpellIgnoreEdit;
-		break;
-
 	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 	// smart quotes
 	case id_CHECK_SMART_QUOTES_ENABLE:
@@ -888,8 +848,6 @@ PtWidget_t *AP_QNXDialog_Options::_lookupWidget ( tControl id )
 
 	case id_CHECK_OTHER_DEFAULT_DIRECTION_RTL:
 		return m_checkbuttonOtherDirectionRtl;
-	case id_CHECK_OTHER_SAVE_CONTEXT_GLYPHS:
-		return m_checkbuttonOtherSaveContextGlyphs;
 	case id_CHECK_OTHER_HEBREW_CONTEXT_GLYPHS:
 		return m_checkbuttonOtherHebrewContextGlyphs;
 
@@ -917,18 +875,6 @@ PtWidget_t *AP_QNXDialog_Options::_lookupWidget ( tControl id )
 		return m_checkbuttonViewCursorBlink;
 		break;
 
-	case id_CHECK_VIEW_SHOW_STANDARD_TOOLBAR:
-		return m_checkbuttonViewShowStandardBar;
-		break;
-
-	case id_CHECK_VIEW_SHOW_FORMAT_TOOLBAR:
-		return m_checkbuttonViewShowFormatBar;
-		break;
-
-	case id_CHECK_VIEW_SHOW_EXTRA_TOOLBAR:
-		return m_checkbuttonViewShowExtraBar;
-		break;
-
 	case id_CHECK_VIEW_SHOW_STATUS_BAR:
 		return m_checkbuttonViewShowStatusBar;
 		break;
@@ -1016,13 +962,9 @@ DEFINE_GET_SET_BOOL(SpellInternet);
 DEFINE_GET_SET_BOOL(SmartQuotesEnable);
 DEFINE_GET_SET_BOOL(PrefsAutoSave);
 DEFINE_GET_SET_BOOL(ViewShowRuler);
-DEFINE_GET_SET_BOOL(ViewShowStandardBar);
-DEFINE_GET_SET_BOOL(ViewShowFormatBar);
-DEFINE_GET_SET_BOOL(ViewShowExtraBar);
 DEFINE_GET_SET_BOOL(ViewShowStatusBar);
 
 DEFINE_GET_SET_BOOL(OtherDirectionRtl);
-DEFINE_GET_SET_BOOL(OtherSaveContextGlyphs);
 DEFINE_GET_SET_BOOL(OtherHebrewContextGlyphs);
 
 /* File save options related stuff */
@@ -1108,4 +1050,12 @@ void	AP_QNXDialog_Options::_setDefaultPageSize(fp_PageSize::Predefined pre)
 	// FIXME: replace this with *real* gui code
 	defaultPageSize = pre;
 }
+void AP_QNXDialog_Options::_setViewShowToolbar(UT_uint32 row, bool b)
+{
 
+
+}
+bool AP_QNXDialog_Options::_gatherViewShowToolbar(UT_uint32 row)
+{
+
+}
